package com.mx.dla.dda.contrato.condicionesTransaccion.daos;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.CategoriaMgDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoCategoriasDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoPtAnnioDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoPtCmgDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoPtransDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoPtrsPrecioDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ContratoPtrsRdDTO;
import com.mx.dla.dda.contrato.condicionesTransaccion.dtos.ReleaseDateDTO;

public interface CatalogosTransaccionDAO {
	
	//DDA_C_CATEGORIA_MG MG,DDA_C_BOXOFFICE BOX
	public List<CategoriaMgDTO> obtenerCategoriaMG();
	
	//DDA_C_RELEASE_DATE
	public List<ReleaseDateDTO> obtenerReleaseDate();
	
	public List<ContratoPtransDTO> verificaTransaccion(@Param("idContrato")Long idContrato);
	public List<ContratoPtAnnioDTO> cargaContratoPagoAnnio(@Param("idContratoPtrans")Long idContratoPtrans);
	public List<ContratoPtCmgDTO> cargaContratoPagoCmg(@Param("idContratoPtrans")Long idContratoPtrans);
	public List<ContratoCategoriasDTO> cargaContratoPagoCategorias(@Param("idContratoPtrans")Long idContratoPtrans);
	public List<ContratoPtrsRdDTO> cargaContratoPagoRD(@Param("idContratoPtrans")Long idContratoPtrans);
	public List<ContratoPtrsPrecioDTO> cargaContratoPagoPrecio(@Param("idContratoPtrans")Long idContratoPtrans);

}
